
/**
 * Counter of clickable strings, used to
 * view an image.
 */
var viewTextCnt = 0; 


/**
 * This function is called when the mouse enters or exits
 * the area above the span containing the view text
 */
function viewText_mouseHover(/*Event*/ event)
{
     var target = (event.target) ? event.target : event.srcElement;
     target.className = event.type == "mouseover" ? "viewTextOver" : "viewText";
}

/**
 * Processes clicks on viewText
 */
function viewText_onClick(/*Event*/ event)
{
    var target = (event.target) ? event.target : event.srcElement;

    // Let's find out, if video is viewed or not. We can do this
    // by checking the pressed attribute previously set by this
    // function or the "addViewText()" function.
    if(target.pressed)
    {
        removeMediaContent(target);
    }
    else {
        addMediaContent(target);
    }
}

function removeMediaContent(/*Element*/ viewElement)
{
    viewElement.pressed = false;
    // change its text to viewText from settings.js
    if(viewElement.hasChildNodes()){
        viewElement.removeChild(viewElement.firstChild);
    }
    viewElement.appendChild(document.createTextNode(viewText));
    
    var container = document.getElementById("container_" + viewElement.embedID);
    
    if (container == null)
    {
        return;
    }
    
    container.parentNode.removeChild(container);
}

/**
 * This function adds a video, or an image to the message.
 */
function addMediaContent(/*Element*/ viewElement)
{
    // set the element as pressed
    viewElement.pressed = true;
    // change its text to hideText from settings.js
    if(viewElement.hasChildNodes()){
        viewElement.removeChild(viewElement.firstChild);
    }
    viewElement.appendChild(document.createTextNode(hideText));
    
    // this will indicate, if adding was succesful.
    var success = false;
    
    // create new div which will contain the image or vid.
    var container = document.createElement("div");
    container.id = "container_" + viewElement.embedID;
    container.className = "mediaContainer";
    
    // viewElement.message is reference to message, that contains 
    // the hyperlink. It has been previously added in addViewText() function. 
    viewElement.message.appendChild(container);
        
    // Call specifed functions for different content type. Any of these
    // functions can be found in it's corresponding file (youtube.js, etc.)
    switch (viewElement.type)
    {
        case "image":
            success = appendImage(container, viewElement);
            break;
        case "youtube":
            success = appendYouTubeVideo(container, viewElement);
    }
    
    if(!success){
        displayError(container, viewElement.type);
    }
}

/**
 * Displays an error message in media container.
 */
function displayError(/*Element*/ container, /*String */ contentType)
{
    var text = "";
    switch(contentType)
    {
        case "image":
            text = "Error: Image can't be viewed. Try again.";
            break;
        case "youtube":
            text = "Error: Video can't be viewed. Try again.";
            break;
    }
    
    var errDiv = document.createElement("div");
    errDiv.style.margin = "20px auto 20px auto";
    errDiv.style.fontWeight = "bold";
    errDiv.appendChild(document.createTextNode(text));
    container.appendChild(errDiv);
}

/**
 * Purpose of this function is to call "createEmbedLinks" function
 * on the first message in group. For other messages the "createEmbedLinks" 
 * function is called directly after grouping.
 */
function startEmbeding()
{
    // Get the message by it's id
    var message = document.getElementById("toBeAnalyzed");
    if (message == null) { return; }
    // We don't want this message to be analyzed more then
    // once, so we set its id to nothing.
    message.id = null;
    // and finaly call the createEmbedLinks function
    createEmbedLinks(message);
}

/**
 * This function searches for hyperlinks in given
 * message. Then it uses specified functions to find
 * if the hyperlink leads to an image, flash video etc.
 */
function createEmbedLinks(/*Element*/ message)
{
    // Searches for all hyperlinks. IEView automaticly
    // sets the class of hyperlinks to be "link".
    // That means that we can search for them by className.
    var links = getElementsByClassName("link", "a", message); 
    
    // Let's test all hyperlinks, if any of them matches 
    // the specified pattern. (for image, video, etc.)
    for (var i = 0; i < links.length; i++) {
        var link = links[i];
        // all next functions search for pattern, that
        // matches images/videos. And if they find a 
        // match, they add a clickable text after the hyperlink.
        processImage(link, message);
        processYouTube(link, message);
    }
}

/**
 * Adds a clickable text, which can be used to play videos,
 * view images, etc. IEView automaticly opens html hyperlinks 
 * (anchors, tag <a>) in default windows browser. That's why
 * we need to create another element (<span>) which will act
 * like a hyperlink and react to mouse clicks.
 */
function addViewText(/*String*/ type, /*Element*/ link, /*Element*/ message)
{
    // Get an id and increment the counter (global variable).
    var id = viewTextCnt++;
    
    // create a span that will be used by user to view/hide imgs/vids.
    var text = document.createTextNode(viewText);
    var blank1 = document.createTextNode(" ");
    var blank2 = document.createTextNode(" ");
    var span = document.createElement("span");
    span.appendChild(text);
    
    // Additional information stored in the span for future use
    // will be used by functions raised by its events.
    span.pressed = false;
    span.type = type;
    span.id = "view_" + id;
    span.embedID = id;
    span.message = message;
    span.url = link.getAttribute("href");
    span.className = "viewText";
    
    // Attaching events in either IE and W3C style. That's 
    // because I use firefox for debugging purposes
    if (span.attachEvent)
    {
        span.attachEvent("onmouseover", viewText_mouseHover);
        span.attachEvent("onmouseout", viewText_mouseHover);
        span.attachEvent("onclick", viewText_onClick);
    }
    else
    {
        span.onmouseover = viewText_mouseHover;
        span.onmouseout = viewText_mouseHover;
        span.onclick = viewText_onClick;        
    }
    
    // Insert the text after the given link. Function
    // is defined in browser.js
    insertAfter(blank1, link);
    insertAfter(span, blank1);
    insertAfter(blank2, span);
}

/**
 * Sets the visibility for the right file message. If sender = user,
 * then outgoing file message will be shown. Incomming message will
 * be shown otherwise.
 */
function showFileMessage(/*String*/ sender, /*String*/ user)
{
    // incomming file message
    var infile = document.getElementById("infile");
    // outgoing file message
    var outfile = document.getElementById("outfile");
    
    if (infile == null || outfile == null) { return; }
    
    infile.id = null;
    outfile.id = null;    
    
    if (sender == user)
    {
        outfile.style.display = "";
    }
    else
    {
        infile.style.display = "";
    }
}


